@@ -3,6 +3,7 @@
 # email:yuyc@ishangqi.com
 # date:2021/11/11 8:06 下午
 # Copyright (C) 2021 The lesscode Team
+import asyncio
 import os
 import sys
 import logging
@@ -21,6 +22,7 @@ from tornado_sqlalchemy import SQLAlchemy
 from lesscode.db.init_connection_pool import InitConnectionPool
 from lesscode.extend_handlers.not_found_handler import NotFoundHandler
 from lesscode.web.router_mapping import RouterMapping
+import platform
 
 define("application_name", default=f"{os.path.split(os.path.dirname(sys.argv[0]))[-1]}", type=str, help="配置文件")
 define("project_name", default=f"{os.path.split(os.path.dirname(sys.argv[0]))[-1]}", type=str, help="配置文件")
@@ -140,6 +142,8 @@ class WebServer:
         self.server = tornado.httpserver.HTTPServer(self.app, max_buffer_size=500 * 1024 * 1024, xheaders=True)  # 500M
 
     def start(self, num_processes: Optional[int] = 1, max_restarts: int = None):
+        if platform.system() == "Windows":
+            asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())
         self.service_register()
         self.server.listen(options.port)
         self.server.start(num_processes, max_restarts)
